summaryrefslogtreecommitdiffstats
path: root/Lib/distutils/command/config.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/distutils/command/config.py')
-rw-r--r--Lib/distutils/command/config.py9
1 files changed, 6 insertions, 3 deletions
diff --git a/Lib/distutils/command/config.py b/Lib/distutils/command/config.py
index 18d7992..ce6cff8 100644
--- a/Lib/distutils/command/config.py
+++ b/Lib/distutils/command/config.py
@@ -325,16 +325,19 @@ class config (Command):
# check_func ()
def check_lib (self, library, library_dirs=None,
- headers=None, include_dirs=None):
+ headers=None, include_dirs=None, other_libraries=[]):
"""Determine if 'library' is available to be linked against,
without actually checking that any particular symbols are provided
by it. 'headers' will be used in constructing the source file to
be compiled, but the only effect of this is to check if all the
- header files listed are available.
+ header files listed are available. Any libraries listed in
+ 'other_libraries' will be included in the link, in case 'library'
+ has symbols that depend on other libraries.
"""
self._check_compiler()
return self.try_link("int main (void) { }",
- headers, include_dirs, [library], library_dirs)
+ headers, include_dirs,
+ [library]+other_libraries, library_dirs)
def check_header (self, header, include_dirs=None,
library_dirs=None, lang="c"):